@@ -482,11 +482,20 @@ class cmake_new(object):
             write_to_log(out)
             return BuildResults(proj, 1, out, '', started, datetime.now())
 
-        toolchain = find_path(
-            os.path.join('lcg-toolchains', 'LCG_{}'.format(LCG_VERSION),
-                         '{}.cmake'.format(os.environ['BINARY_TAG'])),
-            search_path=self._env(proj).get('CMAKE_PREFIX_PATH',
-                                            '').split(os.pathsep))
+        # When the configuration sets LCG_EXTERNALS_FILE, we have to use the
+        # toolchain special/lcg-nightly.cmake
+        if 'LCG_EXTERNALS_FILE' not in kwargs.get('cache_entries', []):
+            toolchain = find_path(
+                os.path.join('lcg-toolchains', 'LCG_{}'.format(LCG_VERSION),
+                             '{}.cmake'.format(os.environ['BINARY_TAG'])),
+                search_path=self._env(proj).get('CMAKE_PREFIX_PATH',
+                                                '').split(os.pathsep))
+        else:
+            toolchain = find_path(
+                os.path.join('lcg-toolchains', 'special', 'lcg-nightly.cmake'),
+                search_path=self._env(proj).get('CMAKE_PREFIX_PATH',
+                                                '').split(os.pathsep))
+
         if not toolchain:
             out = ('\033[0;31mslot configuration error: '
                    'cannot find toolchain file for {} {}\033[0m\n').format(
