@@ -1497,8 +1497,9 @@ class Slot(object):
         if isinstance(self.platforms, basestring):
             self.platforms = [self.platforms]
         for p in self.platforms:
-            assert re.match(r'^[0-9a-z_+]+-[0-9a-z_]+-[0-9a-z_]+-[0-9a-z_+]+$',
-                            p), 'invalid platform: %r' % p
+            assert re.match(
+                r'^[0-9a-z_+]+-[0-9a-z_]+-[0-9a-z_+]+-[0-9a-z_+]+$',
+                p), 'invalid platform: %r' % p
 
         self.error_exceptions = kwargs.get('error_exceptions', [])
         self.warning_exceptions = kwargs.get('warning_exceptions', [])
