@@ -31,7 +31,10 @@ from tempfile import mkstemp
 from datetime import datetime
 from socket import gethostname
 
+from joblib import Parallel, delayed
+
 ARTIFACTS_URL = 'https://lhcb-nightlies-artifacts.web.cern.ch/lhcb-nightlies-artifacts'
+ARTIFACTS_URL_XROOTD = 'root://eosproject.cern.ch//eos/project/l/lhcbwebsites/www/lhcb-nightlies-artifacts'
 
 CHECK_SSL = True
 
@@ -141,13 +144,17 @@ def getURL(url, dst):
         # code copied from shutil.copyfile
         fsrc = None
         fdst = None
+        if url.startswith(ARTIFACTS_URL):
+            try:
+                return getXRootD(
+                    url.replace(ARTIFACTS_URL, ARTIFACTS_URL_XROOTD), dst)
+            except Exception:
+                pass
         try:
             fsrc = urlopen(url)
-            fdst = open(dst, 'wb')
-            shutil.copyfileobj(fsrc, fdst)
+            with open(dst, 'wb') as fdst:
+                shutil.copyfileobj(fsrc, fdst)
         finally:
-            if fdst:
-                fdst.close()
             if fsrc:
                 fsrc.close()
 
@@ -155,10 +162,14 @@ def getURL(url, dst):
         '''Retrieve from 'ssh:'.'''
         call(['scp', '-q', url, dst])
 
+    def getXRootD(url, dst):
+        call(['xrdcp', '--force', '--nopbar', url, dst])
+
     return {
         'http': getHTTP,
         'ssh': getSSH,
-        'file': shutil.copy2
+        'root': getXRootD,
+        'file': shutil.copy2,
     }[protocol](url, dst)
 
 
@@ -596,22 +607,48 @@ class Script(PlainScript):
             pre_existing_indexes = set(findGlimpseFilenames(dest))
 
             index_installed = False
-            for f in required_files:
+
+            def do_install(f):
+                """Worker function for running the installation
+
+                When one process fails all the other running processes are
+                killed. This results in the "finally:" blocks not being called
+                and the temporary files are left hanging around.
+
+                Instead return a tuple of (status, result) where status is a
+                boolean representing if the install was successful. If the
+                install failed, result is an exception that should be raised.
+                """
                 exclude_list = []
                 if opts.no_git:
                     exclude_list.append('*/.git/*')
                 if opts.no_build_dir:
                     exclude_list.append('*/build/*')
-                if install(
-                        url + '/' + f, dest,
-                        exclude=exclude_list):  # 0 or None mean success
-                    raise RuntimeError('error installing %s' % f)
-                installed[f] = datetime.now().isoformat()
+                # Glitches are common so retry up to three times
+                for i in range(3):
+                    if install(
+                            url + '/' + f, dest,
+                            exclude=exclude_list):  # 0 or None mean success
+                        status, result = False, RuntimeError(
+                            'error installing %s' % f)
+                    else:
+                        status, result = True, (f, datetime.now().isoformat())
+                        break
+                return status, result
+
+            installed = {}
+            for status, result in Parallel(n_jobs=-1)(
+                    delayed(do_install)(f) for f in required_files):
+                if status:
+                    installed[result[0]] = result[1]
+                else:
+                    raise result
+
+            for f in installed:
                 # record what has been installed so far
-                histfile = open(history_file, 'w')
-                histfile.writelines(
-                    ['%s:%s\n' % i for i in sorted(installed.items())])
-                histfile.close()
+                with open(history_file, 'w') as histfile:
+                    histfile.writelines(
+                        ['%s:%s\n' % i for i in sorted(installed.items())])
                 if 'index' in f:
                     index_installed = True
             if os.path.exists(os.path.join(dest, 'slot.patch')):
